haptic_morse library

Classes

HapticModel
Haptic Model for storing text, Morse code, and haptic durations.
HapticMorse
A class that converts text to Morse code and haptic patterns.
HapticVibration
Vibration utility for haptic feedback.
Vibration
Platform-independent vibration methods.

Extensions

StringMorseExtension on String
Extension on String to convert to Morse code and haptic patterns.